@@ -1,7 +1,7 @@
 package Config::IOD::Reader;
 
-our $DATE = '2015-03-18'; # DATE
-our $VERSION = '0.10'; # VERSION
+our $DATE = '2015-03-19'; # DATE
+our $VERSION = '0.11'; # VERSION
 
 use 5.010001;
 use strict;
@@ -103,7 +103,12 @@ sub _read_string {
                 $self->{_merge} = @$args ? $args : undef;
             } elsif ($directive eq 'noop') {
             } else {
-                $self->_err("Unknown directive '$directive'");
+                if ($self->{ignore_unknown_directive}) {
+                    # assume a regular comment
+                    next LINE;
+                } else {
+                    $self->_err("Unknown directive '$directive'");
+                }
             }
             next LINE;
         }
@@ -185,7 +190,7 @@ Config::IOD::Reader - Read IOD configuration files
 
 =head1 VERSION
 
-This document describes version 0.10 of Config::IOD::Reader (from Perl distribution Config-IOD-Reader), released on 2015-03-18.
+This document describes version 0.11 of Config::IOD::Reader (from Perl distribution Config-IOD-Reader), released on 2015-03-19.
 
 =head1 SYNOPSIS
 
@@ -376,6 +381,11 @@ config file and force user to use JSON encoding or bracket to specify array:
  [section]
  a=[1,2]
 
+=head2 ignore_unknown_encoding => bool (default: 0)
+
+If set to true, will not die if an unknown directive is encountered. It will
+simply be ignored as a regular comment.
+
 =head1 METHODS
 
 =head2 new(%attrs) => obj
